<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Scheme_Typography;
use Elementor\Widget_Base;

class Osteo_Pricing_Package extends \Elementor\Widget_Base {

    public function get_name() {
        return "Osteo_Pricing_Package";
    }

    public function get_title() {
        return esc_html__( "Osteo Pricing", 'osteo' );
    }

    public function get_icon() {
        return 'eicon-price-table';
    }

    public function get_keywords() {
        return ['pricing table', 'pricing', 'table'];
    }

    public function get_categories() {
        return array( 'Osteo' );
    }

    public static function get_button_sizes() {
        return [
            'xs' => esc_html__( 'Extra Small', 'osteo' ),
            'sm' => esc_html__( 'Small', 'osteo' ),
            'md' => esc_html__( 'Medium', 'osteo' ),
            'lg' => esc_html__( 'Large', 'osteo' ),
            'xl' => esc_html__( 'Extra Large', 'osteo' ),
        ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'osteo_name',
            [
                'label' => esc_html__( 'Name', 'osteo' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'osteo_style',
            [
                'label'       => esc_html__( 'Pricing Style', 'osteo' ),
                'type'        => Controls_Manager::SELECT,
                'default'     => 'style-1',
                'label_block' => false,
                'options'     => [
                    'style-1' => esc_html__( 'Style 1', 'osteo' ),
                    'style-2' => esc_html__( 'Style 2', 'osteo' ),
                    'style-3' => esc_html__( 'Style 3', 'osteo' ),
                    'style-4' => esc_html__( 'Style 4', 'osteo' ),
                    'style-5' => esc_html__( 'Style 5', 'osteo' ),
                    'style-6' => esc_html__( 'Style 6', 'osteo' ),
                    'style-7' => esc_html__( 'Style 7', 'osteo' ),
                ],
            ]
        );

        $this->add_control(
            'osteo_heading_switch',
            [
                'label'        => esc_html__( 'Show Heading', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'osteo_heading',
            [
                'label'     => esc_html__( 'Heading', 'osteo' ),
                'type'      => Controls_Manager::TEXTAREA,
                'default'   => esc_html__( 'Professional', 'osteo' ),
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_subheading_switch',
            [
                'label'        => esc_html__( 'Show Subheading', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'osteo_subheading',
            [
                'label'     => esc_html__( 'Subheading', 'osteo' ),
                'type'      => Controls_Manager::TEXTAREA,
                'default'   => esc_html__( 'Perfect for Small to Medium Business', 'osteo' ),
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_trial_switch',
            [
                'label'        => esc_html__( 'Show Trial', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'osteo_trial',
            [
                'label'     => esc_html__( 'Trial', 'osteo' ),
                'type'      => Controls_Manager::TEXTAREA,
                'default'   => esc_html__( 'Free Trial for 1 Month', 'osteo' ),
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_media_content',
            [
                'label' => esc_html__( 'Media', 'osteo' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'osteo_media_type',
            [
                'label'       => esc_html__( 'Type', 'osteo' ),
                'type'        => Controls_Manager::SELECT,
                'default'     => 'icon',
                'label_block' => false,
                'options'     => [
                    'icon'       => esc_html__( 'Icon', 'osteo' ),
                    'image'      => esc_html__( 'Image', 'osteo' ),
                    'youtube'    => esc_html__( 'Youtube', 'osteo' ),
                    'vimeo'      => esc_html__( 'Vimeo', 'osteo' ),
                    'soundcloud' => esc_html__( 'Soundcloud', 'osteo' ),
                    'popup'      => esc_html__( 'Popup Video', 'osteo' ),
                ],
            ]
        );

        $this->add_control(
            'osteo_media_switch_header',
            [
                'label'        => esc_html__( 'Show Header', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

        $this->add_control(
            'osteo_media_icon_header',
            [
                'label'     => esc_html__( 'Choose Icon', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::ICONS,
                'default'   => [
                    'value'   => 'fas fa-play',
                    'library' => 'solid',
                ],
                'condition' => [
                    'osteo_media_switch_header' => 'yes',
                    'osteo_media_type'          => ['icon', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_image_header',
            [
                'label'     => esc_html__( 'Choose Image', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
                'default'   => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'osteo_media_switch_header' => 'yes',
                    'osteo_media_type'          => ['image', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_image_header_alt',
            [
                'label'     => esc_html__( 'Alt Tag', 'osteo' ),
                'type'      => Controls_Manager::TEXTAREA,
                'condition' => [
                    'osteo_media_switch_header' => 'yes',
                    'osteo_media_type'          => ['image', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_video_id_header',
            [
                'label'     => esc_html__( 'Video ID', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'osteo_media_switch_header' => 'yes',
                    'osteo_media_type'          => ['youtube', 'vimeo'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_soundcloud_id_header',
            [
                'label'     => esc_html__( 'SoundCloud Link', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'osteo_media_switch_header' => 'yes',
                    'osteo_media_type'          => ['soundcloud'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_video_url_header',
            [
                'label'         => esc_html__( 'Video URL', 'osteo' ),
                'type'          => \Elementor\Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'osteo' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '',
                    'is_external' => true,
                    'nofollow'    => true,
                ],
                'condition'     => [
                    'osteo_media_switch_header' => 'yes',
                    'osteo_media_type'          => ['popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_switch_middle',
            [
                'label'        => esc_html__( 'Show Middle', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

        $this->add_control(
            'osteo_media_icon_middle',
            [
                'label'     => esc_html__( 'Choose Icon', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::ICONS,
                'default'   => [
                    'value'   => 'fas fa-play',
                    'library' => 'solid',
                ],
                'condition' => [
                    'osteo_media_switch_middle' => 'yes',
                    'osteo_media_type'          => ['icon', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_image_middle',
            [
                'label'     => esc_html__( 'Choose Image', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
                'default'   => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'osteo_media_switch_middle' => 'yes',
                    'osteo_media_type'          => ['image', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_image_middle_alt',
            [
                'label'     => esc_html__( 'Alt Tag', 'osteo' ),
                'type'      => Controls_Manager::TEXTAREA,
                'condition' => [
                    'osteo_media_switch_middle' => 'yes',
                    'osteo_media_type'          => ['image', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_video_id_middle',
            [
                'label'     => esc_html__( 'Video ID', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'osteo_media_switch_middle' => 'yes',
                    'osteo_media_type'          => ['youtube', 'vimeo'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_soundcloud_id_middle',
            [
                'label'     => esc_html__( 'SoundCloud Link', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'osteo_media_switch_middle' => 'yes',
                    'osteo_media_type'          => ['soundcloud'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_video_url_middle',
            [
                'label'         => esc_html__( 'Video URL', 'osteo' ),
                'type'          => \Elementor\Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'osteo' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '',
                    'is_external' => true,
                    'nofollow'    => true,
                ],
                'condition'     => [
                    'osteo_media_switch_middle' => 'yes',
                    'osteo_media_type'          => ['popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_switch_footer',
            [
                'label'        => esc_html__( 'Show Footer', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

        $this->add_control(
            'osteo_media_icon_footer',
            [
                'label'     => esc_html__( 'Choose Icon', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::ICONS,
                'default'   => [
                    'value'   => 'fas fa-play',
                    'library' => 'solid',
                ],
                'condition' => [
                    'osteo_media_switch_footer' => 'yes',
                    'osteo_media_type'          => ['icon', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_image_footer',
            [
                'label'     => esc_html__( 'Choose Image', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::MEDIA,
                'default'   => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'osteo_media_switch_footer' => 'yes',
                    'osteo_media_type'          => ['image', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_image_footer_alt',
            [
                'label'     => esc_html__( 'Alt Tag', 'osteo' ),
                'type'      => Controls_Manager::TEXTAREA,
                'condition' => [
                    'osteo_media_switch_footer' => 'yes',
                    'osteo_media_type'          => ['image', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_video_id_footer',
            [
                'label'     => esc_html__( 'Video ID', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'osteo_media_switch_footer' => 'yes',
                    'osteo_media_type'          => ['youtube', 'vimeo'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_soundcloud_id_footer',
            [
                'label'     => esc_html__( 'SoundCloud Link', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::TEXTAREA,
                'condition' => [
                    'osteo_media_switch_footer' => 'yes',
                    'osteo_media_type'          => ['soundcloud'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_video_url_footer',
            [
                'label'         => esc_html__( 'Video URL', 'osteo' ),
                'type'          => \Elementor\Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'osteo' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '',
                    'is_external' => true,
                    'nofollow'    => true,
                ],
                'condition'     => [
                    'osteo_media_switch_footer' => 'yes',
                    'osteo_media_type'          => ['popup'],
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_price_content',
            [
                'label' => esc_html__( 'Price', 'osteo' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'osteo_price_switch',
            [
                'label'        => esc_html__( 'Show Price', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'osteo_before_currency_switch',
            [
                'label'        => esc_html__( 'Before Currency Icon', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'yes',
                'condition'    => [
                    'osteo_price_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_before_currency_icon',
            [
                'label'     => esc_html__( 'Currency Icon', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::ICONS,
                'default'   => [
                    'value'   => 'fas fa-dollar-sign',
                    'library' => 'solid',
                ],
                'condition' => [
                    'osteo_price_switch'           => 'yes',
                    'osteo_before_currency_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_after_currency_switch',
            [
                'label'        => esc_html__( 'After Currency Icon', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'no',
                'condition'    => [
                    'osteo_price_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_after_currency_icon',
            [
                'label'     => esc_html__( 'Currency Icon', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::ICONS,
                'default'   => [
                    'value'   => 'fas fa-dollar-sign',
                    'library' => 'solid',
                ],
                'condition' => [
                    'osteo_price_switch'          => 'yes',
                    'osteo_after_currency_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price',
            [
                'label'     => esc_html__( 'Price', 'osteo' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => '10',
                'condition' => [
                    'osteo_price_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_counter',
            [
                'label'     => esc_html__( 'Counter', 'osteo' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'count',
                'options'   => [
                    'count'   => esc_html__( 'No', 'osteo' ),
                    'counter' => esc_html__( 'Yes', 'osteo' ),
                ],
                'condition' => [
                    'osteo_price_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_top_switch',
            [
                'label'        => esc_html__( 'Show Duration Top', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'no',
                'condition'    => [
                    'osteo_price_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_top',
            [
                'label'     => esc_html__( 'Duration Top', 'osteo' ),
                'type'      => Controls_Manager::TEXTAREA,
                'default'   => '/Monthly',
                'condition' => [
                    'osteo_price_switch'              => 'yes',
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration',
            [
                'label'     => esc_html__( 'Duration', 'osteo' ),
                'type'      => Controls_Manager::TEXTAREA,
                'default'   => '/Monthly',
                'condition' => [
                    'osteo_price_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_line_break',
            [
                'label'       => esc_html__( 'Duration Line Break', 'osteo' ),
                'type'        => Controls_Manager::SELECT,
                'default'     => '',
                'label_block' => false,
                'options'     => [
                    ''      => esc_html__( 'No', 'osteo' ),
                    'block' => esc_html__( 'Yes', 'osteo' ),
                ],
                'selectors'   => [
                    '{{WRAPPER}} .duration' => 'display: {{VALUE}};',
                ],
                'condition'   => [
                    'osteo_price_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_features',
            [
                'label' => esc_html__( 'Features', 'osteo' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'osteo_features_switch',
            [
                'label'        => esc_html__( 'Show Features', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'osteo_single_features_icon',
            [
                'label'       => esc_html__( 'Icon', 'osteo' ),
                'type'        => \Elementor\Controls_Manager::ICONS,
                'default'     => [
                    'value'   => 'fas fa-check',
                    'library' => 'solid',
                ],
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'osteo_single_features_icon_color',
            [
                'label'       => esc_html__( 'Icon Color', 'osteo' ),
                'type'        => \Elementor\Controls_Manager::COLOR,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'osteo_single_features',
            [
                'label'       => esc_html__( 'Text', 'osteo' ),
                'type'        => \Elementor\Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Feature', 'osteo' ),
            ]
        );

        $repeater->add_control(
            'osteo_single_features_del',
            [
                'label'       => esc_html__( 'Delete Sign', 'osteo' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'default'     => 'no',
                'label_block' => false,
                'options'     => [
                    'no'  => esc_html__( 'No', 'osteo' ),
                    'del' => esc_html__( 'Yes', 'osteo' ),
                ],
            ]
        );

        $repeater->add_control(
            'osteo_single_features_del_color',
            [
                'label'       => esc_html__( 'Delete Color', 'osteo' ),
                'type'        => \Elementor\Controls_Manager::COLOR,
                'label_block' => true,
                'default'     => "#222",
                'selectors'   => [
                    '{{WRAPPER}} .del' => 'text-decoration-color: {{VALUE}};',
                ],
                'condition'   => [
                    'osteo_single_features_del' => ['del'],
                ],
            ]
        );

        $repeater->start_controls_tabs( 'tabs_features_single_style' );

        $repeater->start_controls_tab(
            'osteo_single_features_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $repeater->add_control(
            'osteo_single_features_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}',
                ],
            ]
        );

        $repeater->add_control(
            'osteo_single_features_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'osteo_single_features_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $repeater->add_control(
            'osteo_single_features_color_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $repeater->add_control(
            'osteo_single_features_bg_color_hover',
            [
                'label'     => esc_html__( 'Background Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $repeater->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'osteo_single_features_typography',
                'label'    => esc_html__( 'Typography', 'osteo' ),
                'scheme'   => Scheme_Typography::TYPOGRAPHY_2,
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
            ]
        );

        $this->add_control(
            'osteo_features_list',
            [
                'label'       => esc_html__( 'Feature List', 'osteo' ),
                'type'        => \Elementor\Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'osteo_feature_list_icon' => [
                            'value'   => 'fas fa-check',
                            'library' => 'solid',
                        ],
                    ],
                    [
                        'osteo_feature_list_icon' => [
                            'value'   => 'fas fa-check',
                            'library' => 'solid',
                        ],
                    ],
                    [
                        'osteo_feature_list_icon' => [
                            'value'   => 'fas fa-check',
                            'library' => 'solid',
                        ],
                    ],
                ],
                'title_field' => '{{osteo_single_features}}',
                'condition'   => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_ribbon_content',
            [
                'label' => esc_html__( 'Ribbon', 'osteo' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'osteo_ribbon',
            [
                'label'       => esc_html__( 'Ribbon Style', 'osteo' ),
                'type'        => Controls_Manager::SELECT,
                'default'     => 'no',
                'label_block' => false,
                'options'     => [
                    'no'             => esc_html__( 'No', 'osteo' ),
                    'ribbon-style-1' => esc_html__( 'Style 1', 'osteo' ),
                    'ribbon-style-2' => esc_html__( 'Style 2', 'osteo' ),
                    'ribbon-style-3' => esc_html__( 'Style 3', 'osteo' ),
                    'ribbon-style-4' => esc_html__( 'Style 4', 'osteo' ),
                    'ribbon-style-5' => esc_html__( 'Style 5', 'osteo' ),
                ],
            ]
        );

        $this->add_control(
            'osteo_ribbon_text',
            [
                'label'     => esc_html__( 'Text', 'osteo' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => 'ribbon-style-3',
                'default'   => 'Best Value',
                'selectors' => [
                    '{{WRAPPER}} .ribbon-style-1::before' => 'content: "{{VALUE}}";',
                    '{{WRAPPER}} .ribbon-style-2::before' => 'content: "{{VALUE}}";',
                    '{{WRAPPER}} .ribbon-style-3::before' => 'content: "{{VALUE}}";',
                    '{{WRAPPER}} .ribbon-style-4::before' => 'content: "{{VALUE}}";',
                ],
                'condition' => [
                    'osteo_ribbon' => ['ribbon-style-1', 'ribbon-style-2', 'ribbon-style-3', 'ribbon-style-4'],
                ],

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_button',
            [
                'label' => esc_html__( 'Button', 'osteo' ),
                'tab'   => \Elementor\Controls_Manager::BUTTON,
            ]
        );

        $this->add_control(
            'osteo_button_switch',
            [
                'label'        => esc_html__( 'Show Button', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'osteo_button_title',
            [
                'label'     => esc_html__( 'Title', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::TEXT,
                'default'   => 'Buy Now',
                'condition' => [
                    'osteo_button_switch' => 'yes',
                ],
            ] );

        $this->add_control(
            'osteo_button_url',
            [
                'label'         => esc_html__( 'URL', 'osteo' ),
                'type'          => \Elementor\Controls_Manager::URL,
                'placeholder'   => 'http://your-link.com',
                'label_block'   => true,
                'default'       => [
                    'url'         => '#',
                    'is_external' => '',
                ],
                'show_external' => true,
                'condition'     => [
                    'osteo_button_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_size',
            [
                'label'     => esc_html__( 'Size', 'osteo' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'sm',
                'options'   => self::get_button_sizes(),
                'condition' => [
                    'osteo_button_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_icon_show',
            [
                'label'     => esc_html__( 'Show Icon', 'osteo' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition' => [
                    'osteo_button_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_icon',
            [
                'label'     => esc_html__( 'Icon', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::ICONS,
                'default'   => [
                    'value'   => 'fas fa-angle-right',
                    'library' => 'solid',
                ],
                'condition' => [
                    'osteo_button_icon_show' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_position',
            [
                'label'     => esc_html__( 'Icon Position', 'osteo' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'before-button-icon',
                'options'   => [
                    'before-button-icon' => esc_html__( 'Before', 'osteo' ),
                    'after-button-icon'  => esc_html__( 'After', 'osteo' ),
                ],
                'condition' => [
                    'osteo_button_icon_show' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_special_note_content',
            [
                'label' => esc_html__( 'Special Note', 'osteo' ),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'osteo_special_note_switch',
            [
                'label'        => esc_html__( 'Show Special Note', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'osteo' ),
                'label_off'    => esc_html__( 'Hide', 'osteo' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'osteo_special_note',
            [
                'label'     => esc_html__( 'Note', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::TEXTAREA,
                'default'   => '10% Discount',
                'condition' => [
                    'osteo_special_note_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_heading_style',
            [
                'label' => esc_html__( 'Name', 'osteo' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'osteo_heading_options',
            [
                'label'     => esc_html__( 'Heading Options', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::HEADING,
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_heading_style' );

        $this->start_controls_tab(
            'osteo_heading_tab',
            [
                'label'     => esc_html__( 'Normal', 'osteo' ),
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_heading_color',
            [
                'label'     => esc_html__( 'Text', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style .heading' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_heading_bg',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style h2' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_heading_hover_tab',
            [
                'label'     => esc_html__( 'Hover', 'osteo' ),
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_heading_color_hover',
            [
                'label'     => esc_html__( 'Text', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .heading' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_heading_bg_hover',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover h2' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_heading_border',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .heading',
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_heading_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .heading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'      => 'osteo_heading_box_shadow',
                'label'     => esc_html__( 'Box Shadow', 'osteo' ),
                'selector'  => '{{WRAPPER}} .heading',
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'osteo_heading_typography',
                'label'     => esc_html__( 'Typography', 'osteo' ),
                'scheme'    => Scheme_Typography::TYPOGRAPHY_1,
                'selector'  => '{{WRAPPER}} .heading',
                'condition' => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_heading_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_heading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_subheading_options',
            [
                'label'     => esc_html__( 'Subheading Options', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::HEADING,
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_subheading_style' );

        $this->start_controls_tab(
            'osteo_subheading_tab',
            [
                'label'     => esc_html__( 'Normal', 'osteo' ),
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_subheading_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subheading' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_subheading_bg',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subheading' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_subheading_hover_tab',
            [
                'label'     => esc_html__( 'Hover', 'osteo' ),
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_subheading_color_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .subheading' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_subheading_bg_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .subheading' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_subheading_border',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .subheading',
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_subheading_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .subheading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'      => 'osteo_subheading_box_shadow',
                'label'     => esc_html__( 'Box Shadow', 'osteo' ),
                'selector'  => '{{WRAPPER}} .subheading',
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'osteo_subheading_typography',
                'label'     => esc_html__( 'Typography', 'osteo' ),
                'scheme'    => Scheme_Typography::TYPOGRAPHY_1,
                'selector'  => '{{WRAPPER}} .subheading',
                'condition' => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_subheading_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .subheading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_subheading_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .subheading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_subheading_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_trial_options',
            [
                'label'     => esc_html__( 'Trial Options', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::HEADING,
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_trial_style' );

        $this->start_controls_tab(
            'osteo_trial_tab',
            [
                'label'     => esc_html__( 'Normal', 'osteo' ),
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_trial_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .trial' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_trial_bg',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .trial' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_trial_hover_tab',
            [
                'label'     => esc_html__( 'Hover', 'osteo' ),
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_trial_color_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .trial' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_trial_bg_hover',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .trial' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_trial_border',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .trial',
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_trial_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .trial' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'      => 'osteo_trial_box_shadow',
                'label'     => esc_html__( 'Box Shadow', 'osteo' ),
                'selector'  => '{{WRAPPER}} .trial',
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'osteo_trial_typography',
                'label'     => esc_html__( 'Typography', 'osteo' ),
                'scheme'    => Scheme_Typography::TYPOGRAPHY_1,
                'selector'  => '{{WRAPPER}} .trial',
                'condition' => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_trial_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .trial' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_trial_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .trial' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_trial_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_media_style',
            [
                'label' => esc_html__( 'Media', 'osteo' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'osteo_media_icon_font_size',
            [
                'label'     => esc_html__( 'Icon Size', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'   => [
                    'size' => 16,
                ],
                'selectors' => [
                    '{{WRAPPER}} .media-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'osteo_media_type' => ['icon'],
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_media_icon_header_border',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .media-icon i',
                'condition' => [
                    'osteo_media_type' => ['icon'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_icon_header_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .media-icon > i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_media_type' => ['icon'],
                ],
            ]
        );

        $this->add_control(
            'osteo_video_width',
            [
                'label'     => esc_html__( 'Width', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'min'       => 5,
                'max'       => 1000,
                'step'      => 20,
                'default'   => 560,
                'condition' => [
                    'osteo_media_type' => ['youtube', 'vimeo'],
                ],
            ]
        );

        $this->add_control(
            'osteo_video_height',
            [
                'label'     => esc_html__( 'Height', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'min'       => 5,
                'max'       => 1000,
                'step'      => 20,
                'default'   => 250,
                'condition' => [
                    'osteo_media_type' => ['youtube', 'vimeo'],
                ],
            ]
        );

        $this->add_control(
            'osteo_audio_width',
            [
                'label'     => esc_html__( 'Weight', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'min'       => 5,
                'max'       => 1000,
                'step'      => 20,
                'default'   => 560,
                'condition' => [
                    'osteo_media_type' => ['soundcloud'],
                ],
            ]
        );

        $this->add_control(
            'osteo_audio_height',
            [
                'label'     => esc_html__( 'Height', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'min'       => 5,
                'max'       => 1000,
                'step'      => 20,
                'default'   => 250,
                'condition' => [
                    'osteo_media_type' => ['soundcloud'],
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_popup_style' );

        $this->start_controls_tab(
            'osteo_popup_tab',
            [
                'label'     => esc_html__( 'Normal', 'osteo' ),
                'condition' => [
                    'osteo_media_type' => ['icon', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_popup_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .media-icon i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .play-btn i'   => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_media_type' => ['icon', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_popup_bg',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .media-icon i' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .play-btn'     => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_media_type' => ['icon', 'popup'],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_popup_hover_tab',
            [
                'label'     => esc_html__( 'Hover', 'osteo' ),
                'condition' => [
                    'osteo_media_type' => ['icon', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_popup_color_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .media-icon:hover i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .play-btn:hover i'   => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_media_type' => ['icon', 'popup'],
                ],
            ]
        );

        $this->add_control(
            'osteo_popup_bg_hover',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .media-icon:hover' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .play-btn:hover'   => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_media_type' => ['icon', 'popup'],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'osteo_media_image_width',
            [
                'label'     => esc_html__( 'Width', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 1000,
                    ],
                ],
                'default'   => [
                    'size' => 200,
                ],
                'selectors' => [
                    '{{WRAPPER}} .osteo-style img' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'osteo_media_type' => ['image'],
                ],
            ]
        );

        $this->add_control(
            'osteo_media_image_height',
            [
                'label'     => esc_html__( 'Height', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 1000,
                    ],
                ],
                'default'   => [
                    'size' => 250,
                ],
                'selectors' => [
                    '{{WRAPPER}} .osteo-style img' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'osteo_media_type' => ['image'],
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'osteo_media_box_shadow',
                'label'    => esc_html__( 'Box Shadow', 'osteo' ),
                'selector' => '{{WRAPPER}} .osteo-style img, .osteo-style iframe, .media-icon > i',
            ]
        );

        $this->add_control(
            'osteo_media_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .osteo-style img'    => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .osteo-style iframe' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .media-icon i'       => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'osteo_media_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .media-icon > i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_media_type' => ['icon'],
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_price_style',
            [
                'label'     => esc_html__( 'Price', 'osteo' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'osteo_price_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_currency_icon_options',
            [
                'label' => esc_html__( 'Icon Options', 'osteo' ),
                'type'  => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'osteo_currency_icon_font_size',
            [
                'label'     => esc_html__( 'Icon Size', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'   => [
                    'size' => 16,
                ],
                'selectors' => [
                    '{{WRAPPER}} .currency i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_currency_icon_style' );

        $this->start_controls_tab(
            'osteo_currency_icon_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_currency_icon_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .currency i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_currency_icon_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_currency_icon_color_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .currency i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'osteo_currency_icon_padding',
            [
                'label'        => esc_html__( 'Padding', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'None', 'osteo' ),
                'label_on'     => esc_html__( 'Custom', 'osteo' ),
                'return_value' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'osteo_currency_icon_padding_left',
            [
                'label'      => esc_html__( 'Padding Left', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 30,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .currency i' => 'padding-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_currency_icon_padding' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_currency_icon_padding_right',
            [
                'label'      => esc_html__( 'Padding Right', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 0,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .currency i' => 'padding-right: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_currency_icon_padding' => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_control(
            'osteo_currency_icon_margin',
            [
                'label'        => esc_html__( 'Margin', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'None', 'osteo' ),
                'label_on'     => esc_html__( 'Custom', 'osteo' ),
                'return_value' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'osteo_currency_icon_margin_left',
            [
                'label'      => esc_html__( 'Margin Left', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 30,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .currency i' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_currency_icon_margin' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_currency_icon_margin_right',
            [
                'label'      => esc_html__( 'Margin Right', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 0,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .currency i' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_currency_icon_margin' => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_control(
            'osteo_price_options',
            [
                'label' => esc_html__( 'Price Options', 'osteo' ),
                'type'  => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->start_controls_tabs( 'tabs_price_counter_style' );

        $this->start_controls_tab(
            'osteo_price_counter_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_price_counter_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .count'   => 'color: {{VALUE}};',
                    '{{WRAPPER}} .counter' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_price_counter_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_price_counter_color_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .count'   => 'color: {{VALUE}};',
                    '{{WRAPPER}} .osteo-style:hover .counter' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'osteo_price_typography',
                'label'    => esc_html__( 'Typography', 'osteo' ),
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .count, .counter',
            ]
        );

        $this->add_control(
            'osteo_price_padding',
            [
                'label'        => esc_html__( 'Padding', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'None', 'osteo' ),
                'label_on'     => esc_html__( 'Custom', 'osteo' ),
                'return_value' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'osteo_price_padding_left',
            [
                'label'      => esc_html__( 'Padding Left', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 30,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .count '  => 'padding-left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .counter' => 'padding-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_padding' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_padding_right',
            [
                'label'      => esc_html__( 'Padding Right', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 0,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .count '  => 'padding-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .counter' => 'padding-right: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_padding' => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_control(
            'osteo_price_margin',
            [
                'label'        => esc_html__( 'Margin', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'None', 'osteo' ),
                'label_on'     => esc_html__( 'Custom', 'osteo' ),
                'return_value' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'osteo_price_margin_left',
            [
                'label'      => esc_html__( 'Margin Left', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 30,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .count '  => 'margin-left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .counter' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_margin' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_margin_right',
            [
                'label'      => esc_html__( 'Margin Right', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 0,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .count '  => 'margin-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .counter' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_margin' => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_control(
            'osteo_price_duration_top_options',
            [
                'label'     => esc_html__( 'Duration Top Options', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::HEADING,
                'condition' => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_price_duration_top_style' );

        $this->start_controls_tab(
            'osteo_price_duration_top_tab',
            [
                'label'     => esc_html__( 'Normal', 'osteo' ),
                'condition' => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_top_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .duration-top' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_top_bg',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .duration-top' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_price_duration_top_hover_tab',
            [
                'label'     => esc_html__( 'Hover', 'osteo' ),
                'condition' => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_top_color_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .duration-top' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_top_bg_hover',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .duration-top' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'osteo_price_duration_top_typography',
                'label'     => esc_html__( 'Typography', 'osteo' ),
                'scheme'    => Scheme_Typography::TYPOGRAPHY_1,
                'selector'  => '{{WRAPPER}} .duration-top',
                'condition' => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_top_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .duration-top' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_top_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .duration-top' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_duration_top_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_options',
            [
                'label' => esc_html__( 'Duration Options', 'osteo' ),
                'type'  => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->start_controls_tabs( 'tabs_price_duration_style' );

        $this->start_controls_tab(
            'osteo_price_duration_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_price_duration_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .duration' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_price_duration_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_price_duration_color_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .duration' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'osteo_price_duration_typography',
                'label'    => esc_html__( 'Typography', 'osteo' ),
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .duration',
            ]
        );

        $this->add_control(
            'osteo_price_duration_padding',
            [
                'label'        => esc_html__( 'Padding', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'None', 'osteo' ),
                'label_on'     => esc_html__( 'Custom', 'osteo' ),
                'return_value' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'osteo_price_duration_padding_left',
            [
                'label'      => esc_html__( 'Padding Left', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 30,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .duration' => 'padding-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_duration_padding' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_padding_right',
            [
                'label'      => esc_html__( 'Padding Right', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 0,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .duration' => 'padding-right: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_duration_padding' => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_control(
            'osteo_price_duration_margin',
            [
                'label'        => esc_html__( 'Margin', 'osteo' ),
                'type'         => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off'    => esc_html__( 'None', 'osteo' ),
                'label_on'     => esc_html__( 'Custom', 'osteo' ),
                'return_value' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'osteo_price_duration_margin_left',
            [
                'label'      => esc_html__( 'Margin Left', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 30,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .duration' => 'margin-left: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_duration_margin' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_duration_margin_right',
            [
                'label'      => esc_html__( 'Margin Right', 'osteo' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', '%'],
                'range'      => [
                    'px' => [
                        'max' => 250,
                    ],
                ],
                'default'    => [
                    'size' => 0,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .duration' => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_price_duration_margin' => 'yes',
                ],
            ]
        );

        $this->end_popover();

        $this->add_control(
            'osteo_price_bg_options',
            [
                'label' => esc_html__( 'BG Options', 'osteo' ),
                'type'  => \Elementor\Controls_Manager::HEADING,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_price_bg_border',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .price',
                'condition' => [
                    'osteo_style' => ['style-1', 'style-2', 'style-3', 'style-4', 'style-6', 'style-7'],
                ],
            ]
        );

        $this->add_control(
            'osteo_price_bg_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .price' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_style' => ['style-1', 'style-2', 'style-3', 'style-4', 'style-6', 'style-7'],
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_price_bg_style' );

        $this->start_controls_tab(
            'osteo_price_bg_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_price_border',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .pricing-header-1:after',
                'condition' => [
                    'osteo_style' => ['style-5'],
                ],
            ]
        );

        $this->add_control(
            'osteo_price_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .pricing-header-1:after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_style' => ['style-5'],
                ],
            ]
        );

        $this->add_control(
            'osteo_price_bg',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_style' => ['style-1', 'style-2', 'style-3', 'style-4', 'style-6', 'style-7'],
                ],
            ]
        );

        $this->add_control(
            'osteo_price_bg_after',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-header-1:after' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_style' => ['style-5'],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_price_bg_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_price_border_hover',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .osteo-style:hover .pricing-header-1:after',
                'condition' => [
                    'osteo_style' => ['style-5'],
                ],
            ]
        );

        $this->add_control(
            'osteo_price_border_radius_hover',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .osteo-style:hover .pricing-header-1:after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_style' => ['style-5'],
                ],
            ]
        );

        $this->add_control(
            'osteo_price_bg_hover',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .price' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_style' => ['style-1', 'style-2', 'style-3', 'style-4', 'style-6', 'style-7'],
                ],
            ]
        );

        $this->add_control(
            'osteo_price_bg_after_hover',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .pricing-header-1:after' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_style' => ['style-5'],
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'osteo_price_box_shadow',
                'label'    => esc_html__( 'Box Shadow', 'osteo' ),
                'selector' => '{{WRAPPER}} .price',
            ]
        );

        $this->add_control(
            'osteo_price_bg_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'osteo_price_bg_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .price' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_single_features_style',
            [
                'label' => esc_html__( 'Features', 'osteo' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'osteo_single_features_options',
            [
                'label'     => esc_html__( 'List Options', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::HEADING,
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_single_features_icon_size',
            [
                'label'     => esc_html__( 'Icon Size', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'default'   => [
                    'size' => 16,
                ],
                'selectors' => [
                    '{{WRAPPER}} .features-list i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_single_features_icon_padding_left',
            [
                'label'     => esc_html__( 'Icon Spacing (Left)', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'default'   => [
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .features-list i' => 'padding-left: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_single_features_icon_padding_right',
            [
                'label'     => esc_html__( 'Icon Spacing (Right)', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'default'   => [
                    'size' => 15,
                ],
                'selectors' => [
                    '{{WRAPPER}} .features-list i' => 'padding-right: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_single_features_border',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .features-list li',
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_single_features_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .features-list li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_single_features_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .features-list li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_single_features_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .features-list li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_features_options',
            [
                'label'     => esc_html__( 'Features Options', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::HEADING,
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_features_border',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .features-list',
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_features_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .features-list' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_features_style' );

        $this->start_controls_tab(
            'osteo_features_tab',
            [
                'label'     => esc_html__( 'Normal', 'osteo' ),
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_features_bg',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .features-list' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_features_hover_tab',
            [
                'label'     => esc_html__( 'Hover', 'osteo' ),
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_features_bg_hover',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:hover .features-list' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'osteo_features_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .features-list' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_features_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .features-list' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_features_switch' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_ribbon_style',
            [
                'label' => esc_html__( 'Ribbon', 'osteo' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'osteo_ribbon_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .ribbon-style-1::before' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .ribbon-style-2::before' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .ribbon-style-3::before' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .ribbon-style-4::before' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'osteo_ribbon' => ['ribbon-style-1', 'ribbon-style-2', 'ribbon-style-3', 'ribbon-style-4'],
                ],
            ]
        );

        $this->add_control(
            'osteo_ribbon_bg_color',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#4CAF50',
                'selectors' => [
                    '{{WRAPPER}} .ribbon-style-1::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .ribbon-style-2::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .ribbon-style-3::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .ribbon-style-4::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .ribbon-style-5::before' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'osteo_ribbon' => ['ribbon-style-1', 'ribbon-style-2', 'ribbon-style-3', 'ribbon-style-4', 'ribbon-style-5'],
                ],
            ]
        );

        $this->add_control(
            'osteo_ribbon_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .ribbon-style-3::before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .ribbon-style-4::before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_ribbon' => ['ribbon-style-3', 'ribbon-style-4'],
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_button_style',
            [
                'label'     => esc_html__( 'Button', 'osteo' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'osteo_button_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_spacing',
            [
                'label'     => esc_html__( 'Icon Spacing', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'default'   => [
                    'size' => 15,
                ],
                'selectors' => [
                    '{{WRAPPER}} .before-button-icon i' => 'padding-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .after-button-icon i'  => 'padding-left: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'osteo_button_icon_show' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_icon_size',
            [
                'label'     => esc_html__( 'Icon Size', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 150,
                    ],
                ],
                'default'   => [
                    'size' => 15,
                ],
                'selectors' => [
                    '{{WRAPPER}} .before-button-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .after-button-icon i'  => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'osteo_button_icon_show' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_effect',
            [
                'label'   => esc_html__( 'Effect', 'osteo' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'                     => esc_html__( 'None', 'osteo' ),
                    'cmk-downup'               => esc_html__( 'DownUp', 'osteo' ),
                    'cmk-updown'               => esc_html__( 'UpDown', 'osteo' ),
                    'cmk-slide-in-vertical'    => esc_html__( 'SlideIn Vertical', 'osteo' ),
                    'cmk-slide-in-horizontal'  => esc_html__( 'SlideIn Horizontal', 'osteo' ),
                    'cmk-slide-out-vertical'   => esc_html__( 'SlideOut Vertical', 'osteo' ),
                    'cmk-slide-out-horizontal' => esc_html__( 'SlideOut Horizontal', 'osteo' ),
                    'cmk-slide-left'           => esc_html__( 'Slide Left', 'osteo' ),
                    'cmk-slide-right'          => esc_html__( 'Slide Right', 'osteo' ),
                    'cmk-slide-up'             => esc_html__( 'Slide Up', 'osteo' ),
                    'cmk-slide-down'           => esc_html__( 'Slide Down', 'osteo' ),
                    'cmk-slideout-horizontal'  => esc_html__( 'SlideOut Horizontal', 'osteo' ),
                    'cmk-slideout-vertical'    => esc_html__( 'SlideOut Vertical', 'osteo' ),
                    'cmk-rotate-left'          => esc_html__( 'Rotate Left', 'osteo' ),
                    'cmk-rotate-right'         => esc_html__( 'Rotate Right', 'osteo' ),
                    'cmk-bounce-left'          => esc_html__( 'Bounce Left', 'osteo' ),
                    'cmk-bounce-right'         => esc_html__( 'Bounce Right', 'osteo' ),
                    'cmk-bounce-up'            => esc_html__( 'Bounce Up', 'osteo' ),
                    'cmk-bounce-down'          => esc_html__( 'Bounce Down', 'osteo' ),
                    'cmk-double-slide-left'    => esc_html__( 'Double Slide Left', 'osteo' ),
                    'cmk-double-slide-right'   => esc_html__( 'Double Slide Right', 'osteo' ),
                    'cmk-double-slide-up'      => esc_html__( 'Double Slide Up', 'osteo' ),
                    'cmk-double-slide-down'    => esc_html__( 'Double Slide Down', 'osteo' ),
                    'cmk-line-left'            => esc_html__( 'Line Left', 'osteo' ),
                    'cmk-line-right'           => esc_html__( 'Line Right', 'osteo' ),
                    'cmk-line-in-vertical'     => esc_html__( 'LineIn Vertical', 'osteo' ),
                    'cmk-line-out-vertical'    => esc_html__( 'LineOut Vertical', 'osteo' ),
                    'cmk-line-in-horizontal'   => esc_html__( 'LineIn Horizontal', 'osteo' ),
                    'cmk-line-out-horizontal'  => esc_html__( 'LineOut Horizontal', 'osteo' ),
                    'cmk-line-bounce-left'     => esc_html__( 'Line Bounce Left', 'osteo' ),
                    'cmk-line-bounce-right'    => esc_html__( 'Line Bounce Right', 'osteo' ),
                    'cmk-double-line-left'     => esc_html__( 'Double Line Left', 'osteo' ),
                    'cmk-double-line-right'    => esc_html__( 'Double Line Right', 'osteo' ),
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_button_style' );

        $this->start_controls_tab(
            'osteo_button_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_button_color',
            [
                'label'     => esc_html__( 'Text', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .cmk-button' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_bg',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '#4CAF50',
                'selectors' => [
                    '{{WRAPPER}} .cmk-button' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_button_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_button_color_hover',
            [
                'label'     => esc_html__( 'Text', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .cmk-button:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_bg_hover',
            [
                'label'     => esc_html__( 'Background', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#2196F3',
                'selectors' => [
                    '{{WRAPPER}} .cmk-button:before' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .cmk-button:after'  => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'osteo_button_border',
                'label'    => esc_html__( 'Border', 'osteo' ),
                'selector' => '{{WRAPPER}} .cmk-button',
            ]
        );

        $this->add_control(
            'osteo_button_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .cmk-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'osteo_button_shadow',
                'selector' => '{{WRAPPER}} .cmk-button',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'osteo_button_typography',
                'label'    => esc_html__( 'Typography', 'osteo' ),
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .cmk-button',
            ]
        );

        $this->add_control(
            'osteo_button_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .cmk-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'osteo_button_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .cmk-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_background_style',
            [
                'label' => esc_html__( 'Background', 'osteo' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs( 'tabs_background_style' );

        $this->start_controls_tab(
            'osteo_background_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'     => 'osteo_background',
                'label'    => esc_html__( 'Background', 'osteo' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .osteo-style',
            ]
        );

        $this->add_control(
            'osteo_background_opacity_color',
            [
                'label'     => esc_html__( 'Opacity Color', 'osteo' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:after' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'osteo_background_opacity',
            [
                'label'     => esc_html__( 'Opacity', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max'  => 1,
                        'step' => 0.1,
                    ],
                ],
                'default'   => [
                    'size' => 0.7,
                ],
                'selectors' => [
                    '{{WRAPPER}} .osteo-style:after' => 'opacity: {{SIZE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_background_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name'     => 'osteo_background_hover',
                'label'    => esc_html__( 'Background', 'osteo' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .osteo-style:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_border_style',
            [
                'label' => esc_html__( 'Border', 'osteo' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs( 'tabs_border_style' );

        $this->start_controls_tab(
            'osteo_border_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'osteo_border',
                'label'    => esc_html__( 'Border', 'osteo' ),
                'selector' => '{{WRAPPER}} .osteo-style',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_border_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'osteo_border_hover',
                'label'    => esc_html__( 'Border', 'osteo' ),
                'selector' => '{{WRAPPER}} .osteo-style:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_special_note_style',
            [
                'label'     => esc_html__( 'Special Note', 'osteo' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'osteo_special_note_switch' => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name'      => 'osteo_special_note_border',
                'label'     => esc_html__( 'Border', 'osteo' ),
                'selector'  => '{{WRAPPER}} .special-note',
                'condition' => [
                    'osteo_special_note_switch' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'osteo_special_note_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .special-note' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'  => [
                    'osteo_special_note_switch' => 'yes',
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_special_note_style' );

        $this->start_controls_tab(
            'osteo_special_note_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_special_note_color',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-note' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_special_note_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_special_note_color_hover',
            [
                'label'     => esc_html__( 'Color', 'osteo' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-note:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'osteo_special_note_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .special-note' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'osteo_special_note_margin',
            [
                'label'      => esc_html__( 'Margin', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .special-note' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'osteo_special_note_typography',
                'label'    => esc_html__( 'Typography', 'osteo' ),
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .special-note',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'osteo_settings_style',
            [
                'label' => esc_html__( 'Settings', 'osteo' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'osteo_settings_effect',
            [
                'label'       => esc_html__( 'Effect', 'osteo' ),
                'type'        => Controls_Manager::SELECT,
                'default'     => 'no',
                'label_block' => false,
                'options'     => [
                    'no'                 => esc_html__( 'No', 'osteo' ),
                    'transform-effect-1' => esc_html__( 'Effect 1', 'osteo' ),
                    'transform-effect-2' => esc_html__( 'Effect 2', 'osteo' ),
                ],

            ]
        );

        $this->add_control(
            'osteo_settings_align',
            [
                'label'       => esc_html__( 'Text Align', 'osteo' ),
                'type'        => Controls_Manager::SELECT,
                'default'     => 'left',
                'label_block' => false,
                'options'     => [
                    'left'   => esc_html__( 'Left', 'osteo' ),
                    'center' => esc_html__( 'Center', 'osteo' ),
                    'right'  => esc_html__( 'Right', 'osteo' ),
                ],
                'selectors'   => [
                    '{{WRAPPER}} .pricing-package-1-style-1' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .pricing-package-1-style-2' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .pricing-package-1-style-3' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .pricing-package-1-style-4' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .pricing-package-1-style-5' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .pricing-package-1-style-6' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .pricing-package-1-style-7' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'osteo_settings_transition',
            [
                'label'     => esc_html__( 'Transition', 'osteo' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max'  => 3,
                        'step' => 0.1,
                    ],
                ],
                'default'   => [
                    'size' => 0.3,
                ],
                'selectors' => [
                    '{{WRAPPER}} .transition, .heading, .subheading, .trial' => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover'                         => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover h2'                      => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .heading'                => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .subheading'             => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .trial'                  => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover h3'                      => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .features-list li, .currency i'             => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .count, .counter, .duration, .special-note' => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .currency i'             => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .features-list'                             => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .pricing-header-1:after'                    => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .pricing-header-1:after' => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .count'                  => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .counter'                => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .duration'               => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .features-list li'       => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .osteo-style:hover .special-note'           => 'transition: {{SIZE}}s;',
                    '{{WRAPPER}} .popup-video i'                             => 'transition: {{SIZE}}s;',
                ],
            ]
        );

        $this->start_controls_tabs( 'tabs_settings_style' );

        $this->start_controls_tab(
            'osteo_settings_tab',
            [
                'label' => esc_html__( 'Normal', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_settings_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .osteo-style' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'osteo_settings_box_shadow',
                'selector' => '{{WRAPPER}} .osteo-style',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'osteo_settings_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'osteo' ),
            ]
        );

        $this->add_control(
            'osteo_settings_border_radius_hover',
            [
                'label'      => esc_html__( 'Border Radius', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .osteo-style:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'osteo_settings_box_shadow_hover',
                'selector' => '{{WRAPPER}} .osteo-style:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'osteo_settings_padding',
            [
                'label'      => esc_html__( 'Padding', 'osteo' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .osteo-style' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute( 'pricing-table-button', 'href', esc_url( $settings['osteo_button_url']['url'] ) );
        $this->add_render_attribute( 'video-url', 'href', esc_url( $settings['osteo_media_video_url_header']['url'] ) );

        if ( !empty( $settings['osteo_button_url']['is_external'] ) ) {
            $this->add_render_attribute( 'pricing-table-button', 'target', '_blank' );
        }
        if ( !empty( $settings['osteo_button_url']['nofollow'] ) ) {
            $this->add_render_attribute( 'pricing-table-button', 'rel', 'nofollow' );
        }

        if ( !empty( $settings['osteo_media_video_url_header']['is_external'] ) ) {
            $this->add_render_attribute( 'video-url', 'target', '_blank' );
        }
        if ( !empty( $settings['osteo_media_video_url_header']['nofollow'] ) ) {
            $this->add_render_attribute( 'video-url', 'rel', 'nofollow' );
        }

        ?>

    <?php if ( 'style-1' === $settings['osteo_style'] ): ?>

		<div class="pricing-package-1-style-1 osteo-style transition ribbon-style overflow <?php echo esc_attr( $settings['osteo_ribbon'] ); ?> <?php echo esc_attr( $settings['osteo_settings_effect'] ); ?>">
			<?php
if ( 'yes' === $settings['osteo_media_switch_header'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_header'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_heading_switch'] ) {
            ?>
						<h2 class="heading transition"><?php echo esc_html( $settings['osteo_heading'] ); ?></h2>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_subheading_switch'] ) {
            ?>
						<h3 class="subheading transition"><?php echo esc_html( $settings['osteo_subheading'] ); ?></h3>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_middle'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_middle'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_features_switch'] ) {
            ?>
						<div class="features-list">
							<ul>
								<?php foreach ( $settings['osteo_features_list'] as $item ): ?>
									<li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?> <?php echo esc_attr( $item['osteo_single_features_del'] ); ?>">
										<span class="<?php echo esc_attr( $settings['osteo_features_icon_position'] ); ?>" style="color: <?php echo esc_attr( $item['osteo_single_features_icon_color'] ); ?>">
											<?php \Elementor\Icons_Manager::render_icon( $item['osteo_single_features_icon'], ['aria-hidden' => 'true'] );?>
										</span>
										<?php echo esc_html($item['osteo_single_features']); ?>
									</li>
								<?php endforeach;?>
							</ul>
						</div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_duration_top_switch'] ) {
            ?>
						<h6 class="duration-top transition"><?php echo esc_html( $settings['osteo_price_duration_top'] ); ?></h6>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_switch'] ) {
            ?>
						<h5 class="price transition">
							<span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_before_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="<?php echo esc_attr( $settings['osteo_price_counter'] ); ?>"><?php echo esc_html( $settings['osteo_price'] ); ?></span><span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_after_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="duration"><?php echo esc_html( $settings['osteo_price_duration'] ); ?></span>
						</h5>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_trial_switch'] ) {
            ?>
						<h4 class="trial transition"><?php echo esc_html( $settings['osteo_trial'] ); ?></h4>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_button_switch'] ) {
            ?>
						<a <?php $this->print_render_attribute_string( 'pricing-table-button' );?> class="cmk-button <?php echo esc_attr( $settings['osteo_button_size'] ); ?> <?php echo esc_attr( $settings['osteo_button_effect'] ); ?>">
							<span class="<?php echo esc_attr( $settings['osteo_button_position'] ); ?>">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_button_icon'], ['aria-hidden' => 'true'] );?>
							</span>
							<?php echo esc_html( $settings['osteo_button_title'] ); ?>
						</a>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_special_note_switch'] ) {
            ?>
						<div class="special-note"><?php echo esc_html( $settings['osteo_special_note'] ); ?></div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_footer'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_footer'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>
		</div>

	<?php elseif ( 'style-2' === $settings['osteo_style'] ): ?>

		<div class="pricing-package-1-style-2 osteo-style transition ribbon-style overflow <?php echo esc_attr( $settings['osteo_ribbon'] ); ?> <?php echo esc_attr( $settings['osteo_settings_effect'] ); ?>">
			<?php
if ( 'yes' === $settings['osteo_media_switch_header'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_header'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_heading_switch'] ) {
            ?>
						<h2 class="heading transition"><?php echo esc_html( $settings['osteo_heading'] ); ?></h2>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_subheading_switch'] ) {
            ?>
						<h3 class="subheading transition"><?php echo esc_html( $settings['osteo_subheading'] ); ?></h3>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_middle'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_middle'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_duration_top_switch'] ) {
            ?>
						<h6 class="duration-top transition"><?php echo esc_html( $settings['osteo_price_duration_top'] ); ?></h6>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_switch'] ) {
            ?>
						<h5 class="price transition">
							<span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_before_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="<?php echo esc_attr( $settings['osteo_price_counter'] ); ?>"><?php echo esc_html( $settings['osteo_price'] ); ?></span><span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_after_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="duration"><?php echo esc_html( $settings['osteo_price_duration'] ); ?></span>
						</h5>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_trial_switch'] ) {
            ?>
						<h4 class="trial transition"><?php echo esc_html( $settings['osteo_trial'] ); ?></h4>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_features_switch'] ) {
            ?>
						<div class="features-list">
							<ul>
								<?php foreach ( $settings['osteo_features_list'] as $item ): ?>
									<li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?> <?php echo esc_attr( $item['osteo_single_features_del'] ); ?>">
										<span class="<?php echo esc_attr( $settings['osteo_features_icon_position'] ); ?>" style="color:<?php echo esc_attr( $item['osteo_single_features_icon_color'] ); ?>">
											<?php \Elementor\Icons_Manager::render_icon( $item['osteo_single_features_icon'], ['aria-hidden' => 'true'] );?>
										</span>
										<?php echo esc_html($item['osteo_single_features']); ?>
									</li>
								<?php endforeach;?>
							</ul>
						</div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_button_switch'] ) {
            ?>
						<a <?php $this->print_render_attribute_string( 'pricing-table-button' );?> class="cmk-button <?php echo esc_attr( $settings['osteo_button_size'] ); ?> <?php echo esc_attr( $settings['osteo_button_effect'] ); ?>">
							<span class="<?php echo esc_attr( $settings['osteo_button_position'] ); ?>">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_button_icon'], ['aria-hidden' => 'true'] );?>
							</span>
							<?php echo esc_html( $settings['osteo_button_title'] ); ?>
						</a>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_special_note_switch'] ) {
            ?>
						<div class="special-note"><?php echo esc_html( $settings['osteo_special_note'] ); ?></div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_footer'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_footer'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

		</div>

	<?php elseif ( 'style-3' === $settings['osteo_style'] ): ?>

		<div class="pricing-package-1-style-3 osteo-style transition ribbon-style overflow <?php echo esc_attr( $settings['osteo_ribbon'] ); ?> <?php echo esc_attr( $settings['osteo_settings_effect'] ); ?>">
			<?php
if ( 'yes' === $settings['osteo_media_switch_header'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_header'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_heading_switch'] ) {
            ?>
						<h2 class="heading transition"><?php echo esc_html( $settings['osteo_heading'] ); ?></h2>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_subheading_switch'] ) {
            ?>
						<h3 class="subheading transition"><?php echo esc_html( $settings['osteo_subheading'] ); ?></h3>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_middle'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_middle'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_duration_top_switch'] ) {
            ?>
						<h6 class="duration-top transition"><?php echo esc_html( $settings['osteo_price_duration_top'] ); ?></h6>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_switch'] ) {
            ?>
						<h5 class="price transition">
							<span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_before_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="<?php echo esc_attr( $settings['osteo_price_counter'] ); ?>"><?php echo esc_html( $settings['osteo_price'] ); ?></span><span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_after_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="duration"><?php echo esc_html( $settings['osteo_price_duration'] ); ?></span>
						</h5>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_trial_switch'] ) {
            ?>
						<h4 class="trial transition"><?php echo esc_html( $settings['osteo_trial'] ); ?></h4>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_button_switch'] ) {
            ?>
						<a <?php $this->print_render_attribute_string( 'pricing-table-button' );?> class="cmk-button <?php echo esc_attr( $settings['osteo_button_size'] ); ?> <?php echo esc_attr( $settings['osteo_button_effect'] ); ?>">
							<span class="<?php echo esc_attr( $settings['osteo_button_position'] ); ?>">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_button_icon'], ['aria-hidden' => 'true'] );?>
							</span>
							<?php echo esc_html( $settings['osteo_button_title'] ); ?>
						</a>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_special_note_switch'] ) {
            ?>
						<div class="special-note"><?php echo esc_html( $settings['osteo_special_note'] ); ?></div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_features_switch'] ) {
            ?>
						<div class="features-list">
							<ul>
								<?php foreach ( $settings['osteo_features_list'] as $item ): ?>
									<li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?> <?php echo esc_attr( $item['osteo_single_features_del'] ); ?>">
										<span class="<?php echo esc_attr( $settings['osteo_features_icon_position'] ); ?>" style="color:<?php echo esc_attr( $item['osteo_single_features_icon_color'] ); ?>">
											<?php \Elementor\Icons_Manager::render_icon( $item['osteo_single_features_icon'], ['aria-hidden' => 'true'] );?>
										</span>
										<?php echo esc_html($item['osteo_single_features']); ?>
									</li>
								<?php endforeach;?>
							</ul>
						</div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_footer'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_footer'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

		</div>

	<?php elseif ( 'style-4' === $settings['osteo_style'] ): ?>

		<div class="pricing-package-1-style-4 osteo-style transition ribbon-style overflow <?php echo esc_attr( $settings['osteo_ribbon'] ); ?> <?php echo esc_attr( $settings['osteo_settings_effect'] ); ?>">
			<?php
if ( 'yes' === $settings['osteo_media_switch_header'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_header'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_heading_switch'] ) {
            ?>
						<h2 class="heading transition"><?php echo esc_html( $settings['osteo_heading'] ); ?></h2>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_subheading_switch'] ) {
            ?>
						<h3 class="subheading transition"><?php echo esc_html( $settings['osteo_subheading'] ); ?></h3>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_middle'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_middle'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_button_switch'] ) {
            ?>
						<a <?php $this->print_render_attribute_string( 'pricing-table-button' );?> class="cmk-button <?php echo esc_attr( $settings['osteo_button_size'] ); ?> <?php echo esc_attr( $settings['osteo_button_effect'] ); ?>">
							<span class="<?php echo esc_attr( $settings['osteo_button_position'] ); ?>">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_button_icon'], ['aria-hidden' => 'true'] );?>
							</span>
							<?php echo esc_html( $settings['osteo_button_title'] ); ?>
						</a>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_special_note_switch'] ) {
            ?>
						<div class="special-note"><?php echo esc_html( $settings['osteo_special_note'] ); ?></div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_duration_top_switch'] ) {
            ?>
						<h6 class="duration-top transition"><?php echo esc_html( $settings['osteo_price_duration_top'] ); ?></h6>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_switch'] ) {
            ?>
						<h5 class="price transition">
							<span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_before_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="<?php echo esc_attr( $settings['osteo_price_counter'] ); ?>"><?php echo esc_html( $settings['osteo_price'] ); ?></span><span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_after_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="duration"><?php echo esc_html( $settings['osteo_price_duration'] ); ?></span>
						</h5>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_trial_switch'] ) {
            ?>
						<h4 class="trial transition"><?php echo esc_html( $settings['osteo_trial'] ); ?></h4>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_features_switch'] ) {
            ?>
						<div class="features-list">
							<ul>
								<?php foreach ( $settings['osteo_features_list'] as $item ): ?>
									<li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?> <?php echo esc_attr( $item['osteo_single_features_del'] ); ?>">
										<span class="<?php echo esc_attr( $settings['osteo_features_icon_position'] ); ?>" style="color:<?php echo esc_attr( $item['osteo_single_features_icon_color'] ); ?>">
											<?php \Elementor\Icons_Manager::render_icon( $item['osteo_single_features_icon'], ['aria-hidden' => 'true'] );?>
										</span>
										<?php echo esc_html($item['osteo_single_features']); ?>
									</li>
								<?php endforeach;?>
							</ul>
						</div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_footer'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_footer'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

		</div>

	<?php elseif ( 'style-5' === $settings['osteo_style'] ): ?>

		<div class="pricing-package-1-style-5 osteo-style transition ribbon-style overflow <?php echo esc_attr( $settings['osteo_ribbon'] ); ?> <?php echo esc_attr( $settings['osteo_settings_effect'] ); ?>">

			<?php
if ( 'yes' === $settings['osteo_media_switch_header'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_header'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_heading_switch'] ) {
            ?>
						<h2 class="heading transition"><?php echo esc_html( $settings['osteo_heading'] ); ?></h2>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_subheading_switch'] ) {
            ?>
						<h3 class="subheading transition"><?php echo esc_html( $settings['osteo_subheading'] ); ?></h3>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_switch'] ) {
            ?>
						<div class="pricing-header-1">
							<h5 class="price transition">
								<span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_before_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="<?php echo esc_attr( $settings['osteo_price_counter'] ); ?>"><?php echo esc_html( $settings['osteo_price'] ); ?></span><span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_after_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="duration"><?php echo esc_html( $settings['osteo_price_duration'] ); ?></span>
							</h5>
						</div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_trial_switch'] ) {
            ?>
						<h4 class="trial transition"><?php echo esc_html( $settings['osteo_trial'] ); ?></h4>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_middle'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_middle'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_features_switch'] ) {
            ?>
						<div class="features-list">
							<ul>
								<?php foreach ( $settings['osteo_features_list'] as $item ): ?>
									<li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?> <?php echo esc_attr( $item['osteo_single_features_del'] ); ?>">
										<span class="<?php echo esc_attr( $settings['osteo_features_icon_position'] ); ?>" style="color:<?php echo esc_attr( $item['osteo_single_features_icon_color'] ); ?>">
											<?php \Elementor\Icons_Manager::render_icon( $item['osteo_single_features_icon'], ['aria-hidden' => 'true'] );?>
										</span>
										<?php echo esc_html($item['osteo_single_features']); ?>
									</li>
								<?php endforeach;?>
							</ul>
						</div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_button_switch'] ) {
            ?>
						<a <?php $this->print_render_attribute_string( 'pricing-table-button' );?> class="cmk-button <?php echo esc_attr( $settings['osteo_button_size'] ); ?> <?php echo esc_attr( $settings['osteo_button_effect'] ); ?>">
							<span class="<?php echo esc_attr( $settings['osteo_button_position'] ); ?>">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_button_icon'], ['aria-hidden' => 'true'] );?>
							</span>
							<?php echo esc_html( $settings['osteo_button_title'] ); ?>
						</a>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_special_note_switch'] ) {
            ?>
						<div class="special-note"><?php echo esc_html( $settings['osteo_special_note'] ); ?></div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_footer'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_footer'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

		</div>

	<?php elseif ( 'style-6' === $settings['osteo_style'] ): ?>

		<div class="pricing-package-1-style-6 osteo-style transition ribbon-style overflow <?php echo esc_attr( $settings['osteo_ribbon'] ); ?> <?php echo esc_attr( $settings['osteo_settings_effect'] ); ?>">

			<?php
if ( 'yes' === $settings['osteo_media_switch_header'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_header'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_duration_top_switch'] ) {
            ?>
						<h6 class="duration-top transition"><?php echo esc_html( $settings['osteo_price_duration_top'] ); ?></h6>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_switch'] ) {
            ?>
						<h5 class="price transition">
							<span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_before_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="<?php echo esc_attr( $settings['osteo_price_counter'] ); ?>"><?php echo esc_html( $settings['osteo_price'] ); ?></span><span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_after_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="duration"><?php echo esc_html( $settings['osteo_price_duration'] ); ?></span>
						</h5>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_trial_switch'] ) {
            ?>
						<h4 class="trial transition"><?php echo esc_html( $settings['osteo_trial'] ); ?></h4>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_button_switch'] ) {
            ?>
						<a <?php $this->print_render_attribute_string( 'pricing-table-button' );?> class="cmk-button <?php echo esc_attr( $settings['osteo_button_size'] ); ?> <?php echo esc_attr( $settings['osteo_button_effect'] ); ?>">
							<span class="<?php echo esc_attr( $settings['osteo_button_position'] ); ?>">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_button_icon'], ['aria-hidden' => 'true'] );?>
							</span>
							<?php echo esc_html( $settings['osteo_button_title'] ); ?>
						</a>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_special_note_switch'] ) {
            ?>
						<div class="special-note"><?php echo esc_html( $settings['osteo_special_note'] ); ?></div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_heading_switch'] ) {
            ?>
						<h2 class="heading transition"><?php echo esc_html( $settings['osteo_heading'] ); ?></h2>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_subheading_switch'] ) {
            ?>
						<h3 class="subheading transition"><?php echo esc_html( $settings['osteo_subheading'] ); ?></h3>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_middle'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_middle'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_features_switch'] ) {
            ?>
						<div class="features-list">
							<ul>
								<?php foreach ( $settings['osteo_features_list'] as $item ): ?>
									<li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?> <?php echo esc_attr( $item['osteo_single_features_del'] ); ?>">
										<span class="<?php echo esc_attr( $settings['osteo_features_icon_position'] ); ?>" style="color:<?php echo esc_attr( $item['osteo_single_features_icon_color'] ); ?>">
											<?php \Elementor\Icons_Manager::render_icon( $item['osteo_single_features_icon'], ['aria-hidden' => 'true'] );?>
										</span>
										<?php echo esc_html($item['osteo_single_features']); ?>
									</li>
								<?php endforeach;?>
							</ul>
						</div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_footer'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_footer'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

		</div>

	<?php elseif ( 'style-7' === $settings['osteo_style'] ): ?>
		<div class="pricing-package-1-style-7 osteo-style transition ribbon-style overflow <?php echo esc_attr( $settings['osteo_ribbon'] ); ?> <?php echo esc_attr( $settings['osteo_settings_effect'] ); ?>">

			<?php
if ( 'yes' === $settings['osteo_media_switch_header'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_header'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_header'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_header']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_header_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_header'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_duration_top_switch'] ) {
            ?>
						<h6 class="duration-top transition"><?php echo esc_html( $settings['osteo_price_duration_top'] ); ?></h6>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_price_switch'] ) {
            ?>
						<h5 class="price transition">
							<span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_before_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="<?php echo esc_attr( $settings['osteo_price_counter'] ); ?>"><?php echo esc_html( $settings['osteo_price'] ); ?></span><span class="currency"><?php \Elementor\Icons_Manager::render_icon( $settings['osteo_after_currency_icon'], ['aria-hidden' => 'true'] );?></span><span class="duration"><?php echo esc_html( $settings['osteo_price_duration'] ); ?></span>
						</h5>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_trial_switch'] ) {
            ?>
						<h4 class="trial transition"><?php echo esc_html( $settings['osteo_trial'] ); ?></h4>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_heading_switch'] ) {
            ?>
						<h2 class="heading transition"><?php echo esc_html( $settings['osteo_heading'] ); ?></h2>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_subheading_switch'] ) {
            ?>
						<h3 class="subheading transition"><?php echo esc_html( $settings['osteo_subheading'] ); ?></h3>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_middle'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_middle'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_middle'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_middle']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_middle_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_middle'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_features_switch'] ) {
            ?>
						<div class="features-list">
							<ul>
								<?php foreach ( $settings['osteo_features_list'] as $item ): ?>
									<li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?> <?php echo esc_attr( $item['osteo_single_features_del'] ); ?>">
										<span class="<?php echo esc_attr( $settings['osteo_features_icon_position'] ); ?>" style="color: <?php echo esc_attr( $item['osteo_single_features_icon_color'] ); ?>">
											<?php \Elementor\Icons_Manager::render_icon( $item['osteo_single_features_icon'], ['aria-hidden' => 'true'] );?>
										</span>
										<?php echo esc_html($item['osteo_single_features']); ?>
									</li>
								<?php endforeach;?>
							</ul>
						</div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_button_switch'] ) {
            ?>
						<a <?php $this->print_render_attribute_string( 'pricing-table-button' );?> class="cmk-button <?php echo esc_attr( $settings['osteo_button_size'] ); ?> <?php echo esc_attr( $settings['osteo_button_effect'] ); ?>">
							<span class="<?php echo esc_attr( $settings['osteo_button_position'] ); ?>">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_button_icon'], ['aria-hidden' => 'true'] );?>
							</span>
							<?php echo esc_html( $settings['osteo_button_title'] ); ?>
						</a>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_special_note_switch'] ) {
            ?>
						<div class="special-note"><?php echo esc_html( $settings['osteo_special_note'] ); ?></div>
					<?php
}
        ?>

			<?php
if ( 'yes' === $settings['osteo_media_switch_footer'] ) {
            ?>
						<?php if ( 'icon' === $settings['osteo_media_type'] ): ?>
							<span class="media-icon">
								<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
							</span>

						<?php elseif ( 'image' === $settings['osteo_media_type'] ): ?>
							<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">

						<?php elseif ( 'youtube' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://www.youtube.com/embed/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'vimeo' === $settings['osteo_media_type'] ): ?>
							<iframe src="https://player.vimeo.com/video/<?php echo esc_html( $settings['osteo_media_video_id_footer'] ); ?>" width="<?php echo esc_html( $settings['osteo_video_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_video_height'] ); ?>" allowfullscreen></iframe>

						<?php elseif ( 'soundcloud' === $settings['osteo_media_type'] ): ?>
							<iframe width="<?php echo esc_html( $settings['osteo_audio_width'] ); ?>" height="<?php echo esc_html( $settings['osteo_audio_height'] ); ?>" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/<?php echo esc_html( $settings['osteo_media_soundcloud_id_footer'] ); ?>&color=%23ff5500&auto_play=false&hide_related=false&show_comments=true&show_user=true&show_reposts=false&show_teaser=true&visual=true"></iframe>

						<?php elseif ( 'popup' === $settings['osteo_media_type'] ): ?>
							<div class="position-relative">
								<img src="<?php echo esc_html( $settings['osteo_media_image_footer']['url'] ); ?>" alt="<?php echo esc_html( $settings['osteo_media_image_footer_alt'] ); ?>">
								<a <?php $this->print_render_attribute_string( 'video-url' );?> class="play-btn popup-video transition">
									<?php \Elementor\Icons_Manager::render_icon( $settings['osteo_media_icon_footer'], ['aria-hidden' => 'true'] );?>
								</a>
							</div>

							<?php endif;?>
					<?php
}
        ?>

		</div>

	<?php endif;?>

		<?php
}
}